#!/bin/bash
#
# Copyright (c) 2021 Jesús E. <heckyel@hyperbola.info>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

# One of the following: xrandr, xbacklight, kernel
METHOD="xbacklight"

case "${BLOCK_BUTTON}" in
    1) xbacklight -inc 5 ;; # Left click
    3) xbacklight -dec 5 ;; # Right click
esac

URGENT_VALUE=10

case "${METHOD}" in
    xrandr) device="${BLOCK_INSTANCE:-primary}"
            xrandrOutput=$(xrandr --verbose)
            case "${device}" in
                primary) device=$(echo "${xrandrOutput}" | grep 'primary' | head -n 1 | awk -F ' ' '{print $1}') ;;
            esac
            curBrightness=$(echo "${xrandrOutput}" | grep "${device}" -A 5 | grep -i "Brightness" | awk -F ':' '{print $2}')
            ;;
    kernel) device="${BLOCK_INSTANCE:-intel_backlight}"
            maxBrightness=$(cat "/sys/class/backlight/${device}/max_brightness")
            curBrightness=$(cat "/sys/class/backlight/${device}/brightness")
            ;;
    xbacklight) curBrightness=$(xbacklight -get) ;;
esac

if [[ "${curBrightness}" -le 0 ]]; then
    exit
fi

case "${METHOD}" in
    xrandr) percent=$(echo "scale=0;${curBrightness} * 100" | bc -l) ;;
    kernel) percent=$(echo "scale=0;${curBrightness} * 100 / ${maxBrightness}" | bc -l) ;;
    xbacklight) percent=$(echo "scale=0;${curBrightness}" | bc -l) ;;
esac

percent=${percent%.*}

if [[ "${percent}" -le 0 ]]; then
  exit
fi

echo "${percent}%"
echo "${percent}%"
echo ""

if [[ "${percent}" -le "${URGENT_VALUE}" ]]; then
  exit 33
fi
